@@ -8,6 +8,7 @@ from .views import IndexView
 from filters import TemplateFilters
 from flask import Blueprint
 from flask.ext.babel import Babel, gettext as _gettext, lazy_gettext
+from flask.ext.appbuilder.babel.manager import BabelManager
 from flask.ext.login import LoginManager
 from flask.ext.openid import OpenID
 from menu import Menu
@@ -39,6 +40,7 @@ class BaseApp():
     db = None
     # Security Manager
     sm = None
+    babelmanager = None
     
     app_name = ""
     app_theme = ''
@@ -80,7 +82,8 @@ class BaseApp():
         
         # Creating Developer's models
         self.db.create_all()
-        
+    
+        # 
         lm = LoginManager()
         lm.init_app(app)
         lm.login_view = 'login'
@@ -93,6 +96,7 @@ class BaseApp():
                             lm, 
                             oid)
         
+        self.babelmanager = BabelManager(app)
         
         self.app.before_request(self.sm.before_request)
         
